@@ -1,7 +1,7 @@
       SUBROUTINE PCLARFB( SIDE, TRANS, DIRECT, STOREV, M, N, K, V, IV,
      $                    JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
 *     May 1, 1997
@@ -238,7 +238,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CGEBR2D, CGEBS2D,CGEMM,
      $                   CGSUM2D, CLACPY, CLASET, CTRBR2D,
-     $                   CTRBS2D, CTRMM, INFOG1L, INFOG2L, PTOPGET,
+     $                   CTRBS2D, CTRMM, INFOG1L, INFOG2L, PB_TOPGET,
      $                   PBCTRAN
 *     ..
 *     .. Intrinsic Functions ..
@@ -318,7 +318,7 @@
 *
 *           Broadcast V to the other process columns.
 *
-            CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+            CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
             IF( MYCOL.EQ.IVCOL ) THEN
                CALL CGEBS2D( ICTXT, 'Rowwise', ROWBTOP, MPC, K,
      $                       V( IOFFV ), LDV )
@@ -768,7 +768,7 @@
 *
 *           Broadcast V to the other process rows.
 *
-            CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+            CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
             IF( MYROW.EQ.IVROW ) THEN
                CALL CGEBS2D( ICTXT, 'Columnwise', COLBTOP, K, NQC,
      $                       V( IOFFV ), LDV )
