@@ -1,10 +1,10 @@
       SUBROUTINE PCLARZ( SIDE, M, N, L, V, IV, JV, DESCV, INCV, TAU, C,
      $                   IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE
@@ -257,7 +257,7 @@
       EXTERNAL           BLACS_GRIDINFO, CAXPY, CCOPY, CGEBR2D,
      $                   CGEBS2D, CGEMV, CGERC, CGERV2D,
      $                   CGESD2D, CGSUM2D, CLASET, INFOG2L,
-     $                   PTOPGET, PBCTRNV
+     $                   PB_TOPGET, PBCTRNV
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -572,7 +572,7 @@
 *
 *              Broadcast column vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
                IF( MYCOL.EQ.IVCOL ) THEN
 *
                   IPW = MPV+1
@@ -674,8 +674,10 @@
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL CGERC( MPC2, NQV, -TAULOC, WORK, 1,
-     $                              V( IOFFV ), LDV, C( IOFFC2 ), LDC )
+                        IF( MPC2.GT.0 .AND. NQV.GT.0 )
+     $                     CALL CGERC( MPC2, NQV, -TAULOC, WORK, 1,
+     $                                 V( IOFFV ), LDV, C( IOFFC2 ),
+     $                                 LDC )
                      END IF
 *
                   END IF
@@ -798,7 +800,8 @@
 *
 *              Broadcast row vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise',
+     $                       COLBTOP )
                IF( MYROW.EQ.IVROW ) THEN
 *
                   IPW = NQV+1
