@@ -1,10 +1,10 @@
       SUBROUTINE PCLARZB( SIDE, TRANS, DIRECT, STOREV, M, N, K, L, V,
      $                    IV, JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     March 14, 2000
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIRECT, SIDE, STOREV, TRANS
@@ -245,7 +245,7 @@
      $                   CGEBS2D, CGEMM, CGSUM2D, CLACGV,
      $                   CLACPY, CLASET, CTRBR2D, CTRBS2D,
      $                   CTRMM, INFOG2L, PBCMATADD, PBCTRAN,
-     $                   PTOPGET, PXERBLA
+     $                   PB_TOPGET, PXERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          MAX, MIN, MOD
@@ -510,7 +510,7 @@
 *
 *        Broadcast V to the other process rows.
 *
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
          IF( MYROW.EQ.IVROW ) THEN
             CALL CGEBS2D( ICTXT, 'Columnwise', COLBTOP, K, NQC2,
      $                    V( IOFFV ), LDV )
@@ -612,9 +612,10 @@
          DO 80 J = 1, NQC2
             CALL CLACGV( K, WORK( IPV+(J-1)*LV ), 1 )
    80    CONTINUE
-         CALL CGEMM( 'No transpose', 'No transpose', MPC2, NQC2, K,
-     $               -ONE, WORK( IPW ), LW, WORK( IPV ), LV, ONE,
-     $               C( IOFFC2 ), LDC )
+         IF( IOFFC2.GT.0 )
+     $      CALL CGEMM( 'No transpose', 'No transpose', MPC2, NQC2, K,
+     $                  -ONE, WORK( IPW ), LW, WORK( IPV ), LV, ONE,
+     $                  C( IOFFC2 ), LDC )
 *
       END IF
 *
