@@ -1,12 +1,10 @@
       SUBROUTINE PDGBTRF( N, BWL, BWU, A, JA, DESCA, IPIV, AF, LAF,
      $                    WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     April 3, 2000
 *
 *     .. Scalar Arguments ..
       INTEGER            BWL, BWU, INFO, JA, LAF, LWORK, N
@@ -16,7 +14,6 @@
       DOUBLE PRECISION   A( * ), AF( * ), WORK( * )
 *     ..
 *
-*
 *  Purpose
 *  =======
 *
@@ -345,20 +342,21 @@
 *                                TYPE_A = 502: LLD_A >=NB_A, 1.
 *  Reserved        DESCA( 7 ) Reserved for future use.
 *
-*
-*
 *  =====================================================================
 *
 *  Implemented for ScaLAPACK by:
 *     Andrew J. Cleary, Livermore National Lab and University of Tenn.,
-*     and Markus Hegland, Australian Natonal University. Feb., 1997.
+*     and Markus Hegland, Australian National University. Feb., 1997.
 *  Based on code written by    : Peter Arbenz, ETH Zurich, 1996.
+*  Last modified by:  Peter Arbenz, Institute of Scientific Computing,
+*    ETH, Zurich.
 *
 *  =====================================================================
 *
 *     .. Parameters ..
-      DOUBLE PRECISION   ONE, ZERO
+      DOUBLE PRECISION   ONE
       PARAMETER          ( ONE = 1.0D+0 )
+      DOUBLE PRECISION   ZERO
       PARAMETER          ( ZERO = 0.0D+0 )
       INTEGER            INT_ONE
       PARAMETER          ( INT_ONE = 1 )
@@ -372,32 +370,31 @@
 *     ..
 *     .. Local Scalars ..
       INTEGER            APTR, BBPTR, BIPTR, BM, BM1, BM2, BMN, BN, BW,
-     $                   CSRC, DBPTR, FIRST_PROC, I, ICTXT, ICTXT_NEW,
-     $                   ICTXT_SAVE, IDUM3, J, JA_NEW, JPTR, L, LAF_MIN,
-     $                   LBWL, LBWU, LDB, LDBB, LLDA, LM, LMJ, LN, LNJ,
-     $                   LPTR, MYCOL, MYROW, MY_NUM_COLS, NB, NEICOL,
-     $                   NP, NPACT, NPCOL, NPROW, NPSTR, NP_SAVE, NRHS,
-     $                   ODD_N, ODD_SIZE, ODPTR, OFST, PART_OFFSET,
-     $                   PART_SIZE, RETURN_CODE, STORE_N_A,
+     $                   CSRC, DBPTR, FIRST_PROC, I, I1, I2, ICTXT,
+     $                   ICTXT_NEW, ICTXT_SAVE, IDUM3, J, JA_NEW, JPTR,
+     $                   L, LAF_MIN, LBWL, LBWU, LDB, LDBB, LLDA, LM,
+     $                   LMJ, LN, LNJ, LPTR, MYCOL, MYROW, MY_NUM_COLS,
+     $                   NB, NEICOL, NP, NPACT, NPCOL, NPROW, NPSTR,
+     $                   NP_SAVE, NRHS, ODD_N, ODD_SIZE, ODPTR, OFST,
+     $                   PART_OFFSET, PART_SIZE, RETURN_CODE, STORE_N_A,
      $                   WORK_SIZE_MIN
 *     ..
 *     .. Local Arrays ..
       INTEGER            DESCA_1XP( 7 ), PARAM_CHECK( 9, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DAXPY,
-     $                   DESC_CONVERT, DGEMM, DGERV2D, DGESD2D, DLACPY,
-     $                   DLATCPY, DPBTRF, DPOTRF, DSYRK, DTBTRS, DTRMM,
-     $                   DTRRV2D, DTRSD2D, DTRSM, DTRTRS, GLOBCHK,
-     $                   PXERBLA, RESHAPE
+      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
+     $                   DGBTRF, DGEMM, DGER, DGERV2D, DGESD2D, DGETRF,
+     $                   DLACPY, DLASWP, DLATCPY, DSWAP, DTRRV2D,
+     $                   DTRSD2D, DTRSM, GLOBCHK, IGAMX2D, IGEBR2D,
+     $                   IGEBS2D, PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAME
       INTEGER            NUMROC
-      EXTERNAL           LSAME, NUMROC
+      EXTERNAL           NUMROC
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ICHAR, MIN, MOD
+      INTRINSIC          MAX, MIN, MOD
 *     ..
 *     .. Executable Statements ..
 *
@@ -413,9 +410,9 @@
 *
       CALL DESC_CONVERT( DESCA, DESCA_1XP, RETURN_CODE )
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 6*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 6*100+2 )
+      END IF
 *
 *     Get values out of descriptor for use in code.
 *
@@ -429,82 +426,76 @@
 *
 *
       CALL BLACS_GRIDINFO( ICTXT, NPROW, NPCOL, MYROW, MYCOL )
-      NP = NPROW * NPCOL
+      NP = NPROW*NPCOL
 *
 *
 *
-      IF( LWORK .LT. -1) THEN
+      IF( LWORK.LT.-1 ) THEN
          INFO = -11
-      ELSE IF ( LWORK .EQ. -1 ) THEN
+      ELSE IF( LWORK.EQ.-1 ) THEN
          IDUM3 = -1
       ELSE
          IDUM3 = 1
-      ENDIF
+      END IF
 *
-      IF( N .LT. 0 ) THEN
+      IF( N.LT.0 ) THEN
          INFO = -1
-      ENDIF
+      END IF
 *
-      IF( N+JA-1 .GT. STORE_N_A ) THEN
-         INFO = -( 6*100 + 6 )
-      ENDIF
+      IF( N+JA-1.GT.STORE_N_A ) THEN
+         INFO = -( 6*100+6 )
+      END IF
 *
-      IF(( BWL .GT. N-1 ) .OR.
-     $   ( BWL .LT. 0 ) ) THEN
+      IF( ( BWL.GT.N-1 ) .OR. ( BWL.LT.0 ) ) THEN
          INFO = -2
-      ENDIF
+      END IF
 *
-      IF(( BWU .GT. N-1 ) .OR.
-     $   ( BWU .LT. 0 ) ) THEN
+      IF( ( BWU.GT.N-1 ) .OR. ( BWU.LT.0 ) ) THEN
          INFO = -3
-      ENDIF
+      END IF
 *
-      IF( LLDA .LT. (2*BWL+2*BWU+1) ) THEN
-         INFO = -( 6*100 + 6 )
-      ENDIF
+      IF( LLDA.LT.( 2*BWL+2*BWU+1 ) ) THEN
+         INFO = -( 6*100+6 )
+      END IF
 *
-      IF( NB .LE. 0 ) THEN
-         INFO = -( 6*100 + 4 )
-      ENDIF
+      IF( NB.LE.0 ) THEN
+         INFO = -( 6*100+4 )
+      END IF
 *
-      BW = BWU+BWL
+      BW = BWU + BWL
 *
 *     Argument checking that is specific to Divide & Conquer routine
 *
-      IF( NPROW .NE. 1 ) THEN
+      IF( NPROW.NE.1 ) THEN
          INFO = -( 6*100+2 )
-      ENDIF
+      END IF
 *
-      IF( N .GT. NP*NB-MOD( JA-1, NB )) THEN
+      IF( N.GT.NP*NB-MOD( JA-1, NB ) ) THEN
          INFO = -( 1 )
-         CALL PXERBLA( ICTXT,
-     $      'PDGBTRF, D&C alg.: only 1 block per proc',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDGBTRF, D&C alg.: only 1 block per proc'
+     $                 , -INFO )
          RETURN
-      ENDIF
+      END IF
 *
-      IF((JA+N-1.GT.NB) .AND. ( NB.LT.(BWL+BWU+1) )) THEN
+      IF( ( JA+N-1.GT.NB ) .AND. ( NB.LT.( BWL+BWU+1 ) ) ) THEN
          INFO = -( 6*100+4 )
-         CALL PXERBLA( ICTXT,
-     $      'PDGBTRF, D&C alg.: NB too small',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDGBTRF, D&C alg.: NB too small', -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *
 *     Check auxiliary storage size
 *
-      LAF_MIN = (NB+BWU)*(BWL+BWU)+6*(BWL+BWU)*(BWL+2*BWU)
+      LAF_MIN = ( NB+BWU )*( BWL+BWU ) + 6*( BWL+BWU )*( BWL+2*BWU )
 *
-      IF( LAF .LT. LAF_MIN ) THEN
+      IF( LAF.LT.LAF_MIN ) THEN
          INFO = -9
 *        put minimum value of laf into AF( 1 )
          AF( 1 ) = LAF_MIN
-         CALL PXERBLA( ICTXT,
-     $      'PDGBTRF: auxiliary storage error ',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDGBTRF: auxiliary storage error ',
+     $                 -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *     Check worksize
 *
@@ -512,39 +503,37 @@
 *
       WORK( 1 ) = WORK_SIZE_MIN
 *
-      IF( LWORK .LT. WORK_SIZE_MIN ) THEN
-         IF( LWORK .NE. -1 ) THEN
-         INFO = -11
+      IF( LWORK.LT.WORK_SIZE_MIN ) THEN
+         IF( LWORK.NE.-1 ) THEN
+            INFO = -11
 *        put minimum value of work into work( 1 )
-         WORK( 1 ) = WORK_SIZE_MIN
-         CALL PXERBLA( ICTXT,
-     $      'PDGBTRF: worksize error ',
-     $      -INFO )
-         ENDIF
+            WORK( 1 ) = WORK_SIZE_MIN
+            CALL PXERBLA( ICTXT, 'PDGBTRF: worksize error ', -INFO )
+         END IF
          RETURN
-      ENDIF
+      END IF
 *
 *     Pack params and positions into arrays for global consistency check
 *
-      PARAM_CHECK(  9, 1 ) = DESCA(5)
-      PARAM_CHECK(  8, 1 ) = DESCA(4)
-      PARAM_CHECK(  7, 1 ) = DESCA(3)
-      PARAM_CHECK(  6, 1 ) = DESCA(1)
-      PARAM_CHECK(  5, 1 ) = JA
-      PARAM_CHECK(  4, 1 ) = BWU
-      PARAM_CHECK(  3, 1 ) = BWL
-      PARAM_CHECK(  2, 1 ) = N
-      PARAM_CHECK(  1, 1 ) = IDUM3
+      PARAM_CHECK( 9, 1 ) = DESCA( 5 )
+      PARAM_CHECK( 8, 1 ) = DESCA( 4 )
+      PARAM_CHECK( 7, 1 ) = DESCA( 3 )
+      PARAM_CHECK( 6, 1 ) = DESCA( 1 )
+      PARAM_CHECK( 5, 1 ) = JA
+      PARAM_CHECK( 4, 1 ) = BWU
+      PARAM_CHECK( 3, 1 ) = BWL
+      PARAM_CHECK( 2, 1 ) = N
+      PARAM_CHECK( 1, 1 ) = IDUM3
 *
-      PARAM_CHECK(  9, 2 ) = 605
-      PARAM_CHECK(  8, 2 ) = 604
-      PARAM_CHECK(  7, 2 ) = 603
-      PARAM_CHECK(  6, 2 ) = 601
-      PARAM_CHECK(  5, 2 ) = 5
-      PARAM_CHECK(  4, 2 ) = 3
-      PARAM_CHECK(  3, 2 ) = 2
-      PARAM_CHECK(  2, 2 ) = 1
-      PARAM_CHECK(  1, 2 ) = 11
+      PARAM_CHECK( 9, 2 ) = 605
+      PARAM_CHECK( 8, 2 ) = 604
+      PARAM_CHECK( 7, 2 ) = 603
+      PARAM_CHECK( 6, 2 ) = 601
+      PARAM_CHECK( 5, 2 ) = 5
+      PARAM_CHECK( 4, 2 ) = 3
+      PARAM_CHECK( 3, 2 ) = 2
+      PARAM_CHECK( 2, 2 ) = 1
+      PARAM_CHECK( 1, 2 ) = 11
 *
 *     Want to find errors with MIN( ), so if no error, set it to a big
 *     number. If there already is an error, multiply by the the
@@ -555,20 +544,20 @@
       ELSE IF( INFO.LT.-DESCMULT ) THEN
          INFO = -INFO
       ELSE
-         INFO = -INFO * DESCMULT
+         INFO = -INFO*DESCMULT
       END IF
 *
 *     Check consistency across processors
 *
-      CALL GLOBCHK( ICTXT, 9, PARAM_CHECK, 9,
-     $              PARAM_CHECK( 1, 3 ), INFO )
+      CALL GLOBCHK( ICTXT, 9, PARAM_CHECK, 9, PARAM_CHECK( 1, 3 ),
+     $              INFO )
 *
 *     Prepare output: set info = 0 if no error, and divide by DESCMULT
 *     if error is not in a descriptor entry.
 *
       IF( INFO.EQ.BIGNUM ) THEN
          INFO = 0
-      ELSE IF( MOD( INFO, DESCMULT ) .EQ. 0 ) THEN
+      ELSE IF( MOD( INFO, DESCMULT ).EQ.0 ) THEN
          INFO = -INFO / DESCMULT
       ELSE
          INFO = -INFO
@@ -588,15 +577,15 @@
 *     Adjust addressing into matrix space to properly get into
 *        the beginning part of the relevant data
 *
-      PART_OFFSET = NB*( (JA-1)/(NPCOL*NB) )
+      PART_OFFSET = NB*( ( JA-1 ) / ( NPCOL*NB ) )
 *
-      IF ( (MYCOL-CSRC) .LT. (JA-PART_OFFSET-1)/NB ) THEN
+      IF( ( MYCOL-CSRC ).LT.( JA-PART_OFFSET-1 ) / NB ) THEN
          PART_OFFSET = PART_OFFSET + NB
-      ENDIF
+      END IF
 *
-      IF ( MYCOL .LT. CSRC ) THEN
+      IF( MYCOL.LT.CSRC ) THEN
          PART_OFFSET = PART_OFFSET - NB
-      ENDIF
+      END IF
 *
 *     Form a new BLACS grid (the "standard form" grid) with only procs
 *        holding part of the matrix, of size 1xNP where NP is adjusted,
@@ -604,7 +593,7 @@
 *
 *     First processor to hold part of the matrix:
 *
-      FIRST_PROC = MOD( ( JA-1 )/NB+CSRC, NPCOL )
+      FIRST_PROC = MOD( ( JA-1 ) / NB+CSRC, NPCOL )
 *
 *     Calculate new JA one while dropping off unused processors.
 *
@@ -613,12 +602,12 @@
 *     Save and compute new value of NP
 *
       NP_SAVE = NP
-      NP = ( JA_NEW+N-2 )/NB + 1
+      NP = ( JA_NEW+N-2 ) / NB + 1
 *
 *     Call utility routine that forms "standard-form" grid
 *
-      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE,
-     $              FIRST_PROC, INT_ONE, NP )
+      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE, FIRST_PROC,
+     $              INT_ONE, NP )
 *
 *     Use new context from standard grid as context.
 *
@@ -632,9 +621,9 @@
 *
 *     Drop out processors that do not have part of the matrix.
 *
-      IF( MYROW .LT. 0 ) THEN
-         GOTO 1234
-      ENDIF
+      IF( MYROW.LT.0 ) THEN
+         GO TO 210
+      END IF
 *
 *     ********************************
 *     Values reused throughout routine
@@ -649,10 +638,10 @@
 *
 *     Offset in columns to beginning of main partition in each proc
 *
-      IF ( MYCOL .EQ. 0 ) THEN
-        PART_OFFSET = PART_OFFSET+MOD( JA_NEW-1, PART_SIZE )
-        MY_NUM_COLS = MY_NUM_COLS - MOD(JA_NEW-1, PART_SIZE )
-      ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         PART_OFFSET = PART_OFFSET + MOD( JA_NEW-1, PART_SIZE )
+         MY_NUM_COLS = MY_NUM_COLS - MOD( JA_NEW-1, PART_SIZE )
+      END IF
 *
 *     Offset in elements
 *
@@ -669,11 +658,11 @@
          AF( I ) = ZERO
    10 CONTINUE
 *
-      DO 9 J = 1, ODD_SIZE
-         DO 8 I = 1, BW
-            A( I+(J-1)*LLDA ) = ZERO
-    8    CONTINUE
-    9 CONTINUE
+      DO 30 J = 1, ODD_SIZE
+         DO 20 I = 1, BW
+            A( I+( J-1 )*LLDA ) = ZERO
+   20    CONTINUE
+   30 CONTINUE
 *
 *     Begin main code
 *
@@ -685,17 +674,17 @@
 *     Transfer triangle B_i of local matrix to next processor
 *     for fillin. Overlap the send with the factorization of A_i.
 *
-      IF (MYCOL .LE. NPCOL-2) THEN
+      IF( MYCOL.LE.NPCOL-2 ) THEN
 *
 *     The last processor does not need to send anything.
 *     BIPTR = location of triangle B_i in memory
-         BIPTR = (NB-BW)*LLDA + 2*BW+1
+         BIPTR = ( NB-BW )*LLDA + 2*BW + 1
 *
          CALL DTRSD2D( ICTXT, 'U', 'N',
-     $       MIN( BW, BWU+NUMROC( N, NB, MYCOL+1, 0, NPCOL ) ),
-     $       BW, A(BIPTR), LLDA-1, 0, MYCOL+1)
+     $                 MIN( BW, BWU+NUMROC( N, NB, MYCOL+1, 0,
+     $                 NPCOL ) ), BW, A( BIPTR ), LLDA-1, 0, MYCOL+1 )
 *
-      ENDIF
+      END IF
 *
 *     Factor main partition P_i A_i = L_i U_i on each processor
 *
@@ -708,109 +697,116 @@
 *     has a slightly different matrix format than Scalapack the pointer
 *     has to be adjusted on processor MYCOL=0.
 *
-      IF (MYCOL .NE. 0) THEN
+      IF( MYCOL.NE.0 ) THEN
          LBWL = BW
          LBWU = 0
          APTR = 1
       ELSE
          LBWL = BWL
          LBWU = BWU
-         APTR = 1+BWU
-      ENDIF
+         APTR = 1 + BWU
+      END IF
 *
-      IF (MYCOL .NE. NPCOL-1) THEN
+      IF( MYCOL.NE.NPCOL-1 ) THEN
          LM = NB - LBWU
          LN = NB - BW
-      ELSE IF (MYCOL .NE. 0) THEN
+      ELSE IF( MYCOL.NE.0 ) THEN
          LM = ODD_SIZE + BWU
-         LN = MAX(ODD_SIZE-BW,0)
+         LN = MAX( ODD_SIZE-BW, 0 )
       ELSE
          LM = N
          LN = MAX( N-BW, 0 )
-      ENDIF
+      END IF
 *
-      IF (LN .GT. 0) THEN
+      IF( LN.GT.0 ) THEN
 *
-         CALL DGBTRF(LM,LN, LBWL,LBWU, A(APTR),LLDA, IPIV, INFO)
+         CALL DGBTRF( LM, LN, LBWL, LBWU, A( APTR ), LLDA, IPIV, INFO )
 *
          IF( INFO.NE.0 ) THEN
             INFO = INFO + NB*MYCOL
-            GO TO 90
+            GO TO 80
          END IF
 *
          NRHS = BW
-         LDB = LLDA-1
+         LDB = LLDA - 1
 *
 *     Update the last BW columns of A_i (code modified from DGBTRS)
 *
 *     Only the eliminations of unknowns > LN-BW have an effect on
 *     the last BW columns. Loop over them...
 *
-            DO 23 J = MAX(LN-BW+1,1), LN
+         DO 40 J = MAX( LN-BW+1, 1 ), LN
 *
-               LMJ = MIN( LBWL, LM-J )
-               LNJ = MIN( BW, J+BW-LN+APTR-1 )
+            LMJ = MIN( LBWL, LM-J )
+            LNJ = MIN( BW, J+BW-LN+APTR-1 )
 *
-               L = IPIV( J )
+            L = IPIV( J )
 *
-               JPTR = J-(LN+1)+2*BW+1-LBWL + LN*LLDA
+            JPTR = J - ( LN+1 ) + 2*BW + 1 - LBWL + LN*LLDA
 *
-               IF( L.NE.J ) THEN
+            IF( L.NE.J ) THEN
 *
 *        Element (L,LN+1) is swapped with element (J,LN+1) etc
 *        Furthermore, the elements in the same row are LDB=LLDA-1 apart
 *        The complicated formulas are to cope with the banded
 *          data format:
 *
-                  LPTR = L-(LN+1)+2*BW+1-LBWL + LN*LLDA
+               LPTR = L - ( LN+1 ) + 2*BW + 1 - LBWL + LN*LLDA
 *
-                  CALL DSWAP( LNJ, A(LPTR),LDB, A(JPTR), LDB )
+               CALL DSWAP( LNJ, A( LPTR ), LDB, A( JPTR ), LDB )
 *
-               ENDIF
+            END IF
 *
 *              LPTR is the pointer to the beginning of the
 *                 coefficients of L
 *
-               LPTR = BW+1+APTR + (J-1)*LLDA
+            LPTR = BW + 1 + APTR + ( J-1 )*LLDA
 *
-               CALL DGER(LMJ,LNJ,-ONE, A(LPTR),1, A(JPTR),LDB,
-     $           A(JPTR+1),LDB)
-   23       CONTINUE
+            CALL DGER( LMJ, LNJ, -ONE, A( LPTR ), 1, A( JPTR ), LDB,
+     $                 A( JPTR+1 ), LDB )
+   40    CONTINUE
 *
-      ENDIF
+      END IF
 *
 *      Compute spike fill-in, L_i F_i = P_i B_{i-1}
 *
 *      Receive triangle B_{i-1} from previous processor
 *
-      IF (MYCOL .GT. 0) THEN
+      IF( MYCOL.GT.0 ) THEN
+         CALL DTRRV2D( ICTXT, 'U', 'N', MIN( BW, LM ), BW, AF( 1 ), BW,
+     $                 0, MYCOL-1 )
 *
-         CALL DTRRV2D( ICTXT, 'U', 'N', MIN(BW, LM), BW, AF( 1 ),
-     $        LM, 0, MYCOL-1)
+*        Transpose transmitted upper triangular (trapezoidal) matrix
 *
+         DO 60 I2 = 1, MIN( BW, LM )
+            DO 50 I1 = I2 + 1, BW
+               AF( I1+( I2-1 )*BW ) = AF( I2+( I1-1 )*BW )
+               AF( I2+( I1-1 )*BW ) = ZERO
+   50       CONTINUE
+   60    CONTINUE
 *
 *      Permutation and forward elimination (triang. solve)
 *
-         DO 24 J = 1, LN
+         DO 70 J = 1, LN
 *
             LMJ = MIN( LBWL, LM-J )
             L = IPIV( J )
 *
-            IF( L .NE. J ) THEN
+            IF( L.NE.J ) THEN
+               CALL DSWAP( BW, AF( ( L-1 )*BW+1 ), 1,
+     $                     AF( ( J-1 )*BW+1 ), 1 )
+            END IF
 *
-                CALL DSWAP(NRHS,  AF(L), LM, AF(J), LM )
-            ENDIF
+            LPTR = BW + 1 + APTR + ( J-1 )*LLDA
 *
-            LPTR = BW+1+APTR + (J-1)*LLDA
+            CALL DGER( NRHS, LMJ, -ONE, AF( ( J-1 )*BW+1 ), 1,
+     $                 A( LPTR ), 1, AF( J*BW+1 ), BW )
 *
-            CALL DGER( LMJ,NRHS, -ONE, A(LPTR),1,
-     $           AF(J), LM, AF(J+1), LM)
+   70    CONTINUE
 *
-   24   CONTINUE
+      END IF
 *
-      ENDIF
-*
-   90 CONTINUE
+   80 CONTINUE
 *
 ********************************************************************
 *     PHASE 2: Formation and factorization of Reduced System.
@@ -819,53 +815,53 @@
 *     Define the initial dimensions of the diagonal blocks
 *     The offdiagonal blocks (for MYCOL > 0) are of size BM by BW
 *
-      IF (MYCOL .NE. NPCOL-1) THEN
+      IF( MYCOL.NE.NPCOL-1 ) THEN
          BM = BW - LBWU
          BN = BW
       ELSE
-         BM = MIN(BW,ODD_SIZE) + BWU
-         BN = MIN(BW,ODD_SIZE)
-      ENDIF
+         BM = MIN( BW, ODD_SIZE ) + BWU
+         BN = MIN( BW, ODD_SIZE )
+      END IF
 *
 *     Pointer to first element of block bidiagonal matrix in AF
 *     Leading dimension of block bidiagonal system
 *
-      BBPTR = (NB+BWU)*BW + 1
-      LDBB   = 2*BW + BWU
+      BBPTR = ( NB+BWU )*BW + 1
+      LDBB = 2*BW + BWU
 *
 *     Copy from A and AF into block bidiagonal matrix (tail of AF)
 *
 *     DBPTR = Pointer to diagonal blocks in A
-      DBPTR = BW+1 + LBWU + LN*LLDA
+      DBPTR = BW + 1 + LBWU + LN*LLDA
 *
-      CALL DLACPY('G',BM,BN, A(DBPTR),LLDA-1,
-     $     AF(BBPTR + BW*LDBB),LDBB)
+      CALL DLACPY( 'G', BM, BN, A( DBPTR ), LLDA-1, AF( BBPTR+BW*LDBB ),
+     $             LDBB )
 *
 *     Zero out any junk entries that were copied
 *
-      DO 870 J=1, BM
-         DO 880 I=J+LBWL, BM-1
-            AF( BBPTR+BW*LDBB+(J-1)*LDBB+I ) = ZERO
-  880    CONTINUE
-  870 CONTINUE
+      DO 100 J = 1, BM
+         DO 90 I = J + LBWL, BM - 1
+            AF( BBPTR+BW*LDBB+( J-1 )*LDBB+I ) = ZERO
+   90    CONTINUE
+  100 CONTINUE
 *
-      IF (MYCOL .NE. 0) THEN
+      IF( MYCOL.NE.0 ) THEN
 *
 *        ODPTR = Pointer to offdiagonal blocks in A
 *
-         ODPTR = LM-BM+1
-         CALL DLACPY('G',BM,BW, AF(ODPTR),LM,
-     $        AF(BBPTR +2*BW*LDBB),LDBB)
-      ENDIF
+         ODPTR = ( LM-BM )*BW + 1
+         CALL DLATCPY( 'G', BW, BM, AF( ODPTR ), BW,
+     $                 AF( BBPTR+2*BW*LDBB ), LDBB )
+      END IF
 *
-      IF (NPCOL.EQ.1) THEN
+      IF( NPCOL.EQ.1 ) THEN
 *
 *        In this case the loop over the levels will not be
 *        performed.
-         CALL DGETRF( N-LN, N-LN, AF(BBPTR+BW*LDBB), LDBB,
-     $        IPIV(LN+1), INFO)
+         CALL DGETRF( N-LN, N-LN, AF( BBPTR+BW*LDBB ), LDBB,
+     $                IPIV( LN+1 ), INFO )
 *
-      ENDIF
+      END IF
 *
 *     Loop over levels ... only occurs if npcol > 1
 *
@@ -873,198 +869,197 @@
 *     (stride between active processors) are used to control the
 *     loop.
 *
-        NPACT = NPCOL
-        NPSTR = 1
+      NPACT = NPCOL
+      NPSTR = 1
 *
 *       Begin loop over levels
 *
-  200   IF (NPACT .LE. 1) GOTO 300
+  110 CONTINUE
+      IF( NPACT.LE.1 )
+     $   GO TO 190
 *
 *         Test if processor is active
 *
-          IF (MOD(MYCOL,NPSTR) .EQ. 0) THEN
+      IF( MOD( MYCOL, NPSTR ).EQ.0 ) THEN
 *
 *   Send/Receive blocks
 *
 *
-             IF (MOD(MYCOL,2*NPSTR) .EQ. 0) THEN
+         IF( MOD( MYCOL, 2*NPSTR ).EQ.0 ) THEN
 *
 *            This node will potentially do more work later
 *
-                NEICOL = MYCOL + NPSTR
+            NEICOL = MYCOL + NPSTR
 *
-                IF (NEICOL/NPSTR .LT. NPACT-1) THEN
-                   BMN = BW
-                ELSE IF (NEICOL/NPSTR .EQ. NPACT-1) THEN
-                   ODD_N = NUMROC(N, NB, NPCOL-1, 0, NPCOL)
-                   BMN = MIN(BW,ODD_N) + BWU
-                ELSE
+            IF( NEICOL / NPSTR.LT.NPACT-1 ) THEN
+               BMN = BW
+            ELSE IF( NEICOL / NPSTR.EQ.NPACT-1 ) THEN
+               ODD_N = NUMROC( N, NB, NPCOL-1, 0, NPCOL )
+               BMN = MIN( BW, ODD_N ) + BWU
+            ELSE
 *
 *                  Last processor skips to next level
-                   GOTO 250
-                ENDIF
+               GO TO 180
+            END IF
 *
 *               BM1 = M for 1st block on proc pair, BM2 2nd block
 *
-                BM1 = BM
-                BM2 = BMN
+            BM1 = BM
+            BM2 = BMN
 *
-                IF (NEICOL/NPSTR .LE. NPACT-1 )THEN
+            IF( NEICOL / NPSTR.LE.NPACT-1 ) THEN
 *
-                   CALL DGESD2D( ICTXT, BM, 2*BW, AF(BBPTR+BW*LDBB),
-     $                  LDBB, 0, NEICOL )
+               CALL DGESD2D( ICTXT, BM, 2*BW, AF( BBPTR+BW*LDBB ), LDBB,
+     $                       0, NEICOL )
 *
-                   CALL DGERV2D( ICTXT, BMN, 2*BW, AF(BBPTR+BM),
-     $                  LDBB, 0, NEICOL)
+               CALL DGERV2D( ICTXT, BMN, 2*BW, AF( BBPTR+BM ), LDBB, 0,
+     $                       NEICOL )
 *
-                   IF( NPACT .EQ. 2 ) THEN
+               IF( NPACT.EQ.2 ) THEN
 *
 *                     Copy diagonal block to align whole system
 *
-                      CALL DLACPY( 'G', BMN, BW, AF( BBPTR+BM ),
-     $                  LDBB, AF( BBPTR+2*BW*LDBB+BM ), LDBB )
-                   ENDIF
+                  CALL DLACPY( 'G', BMN, BW, AF( BBPTR+BM ), LDBB,
+     $                         AF( BBPTR+2*BW*LDBB+BM ), LDBB )
+               END IF
 *
-                ENDIF
+            END IF
 *
-             ELSE
+         ELSE
 *
 *               This node stops work after this stage -- an extra copy
 *               is required to make the odd and even frontal matrices
 *               look identical
 *
-                NEICOL = MYCOL - NPSTR
+            NEICOL = MYCOL - NPSTR
 *
-                IF (NEICOL .EQ. 0) THEN
-                   BMN = BW - BWU
-                ELSE
-                   BMN = BW
-                ENDIF
+            IF( NEICOL.EQ.0 ) THEN
+               BMN = BW - BWU
+            ELSE
+               BMN = BW
+            END IF
 *
-                BM1 = BMN
-                BM2 = BM
+            BM1 = BMN
+            BM2 = BM
 *
-                CALL DGESD2D( ICTXT, BM, 2*BW, AF(BBPTR+BW*LDBB),
-     $               LDBB, 0, NEICOL )
+            CALL DGESD2D( ICTXT, BM, 2*BW, AF( BBPTR+BW*LDBB ), LDBB, 0,
+     $                    NEICOL )
 *
-                CALL DLACPY('G',BM, 2*BW, AF(BBPTR+BW*LDBB),LDBB,
-     $               AF(BBPTR+BMN),LDBB)
+            CALL DLACPY( 'G', BM, 2*BW, AF( BBPTR+BW*LDBB ), LDBB,
+     $                   AF( BBPTR+BMN ), LDBB )
 *
-                DO 31 J=BBPTR+2*BW*LDBB, BBPTR+3*BW*LDBB-1, LDBB
-                   DO 32 I=0, LDBB-1
-                      AF(I+J) = ZERO
-   32              CONTINUE
-   31           CONTINUE
+            DO 130 J = BBPTR + 2*BW*LDBB, BBPTR + 3*BW*LDBB - 1, LDBB
+               DO 120 I = 0, LDBB - 1
+                  AF( I+J ) = ZERO
+  120          CONTINUE
+  130       CONTINUE
 *
-                CALL DGERV2D( ICTXT, BMN, 2*BW, AF(BBPTR+BW*LDBB),
-     $               LDBB, 0, NEICOL)
+            CALL DGERV2D( ICTXT, BMN, 2*BW, AF( BBPTR+BW*LDBB ), LDBB,
+     $                    0, NEICOL )
 *
-                IF( NPACT .EQ. 2 ) THEN
+            IF( NPACT.EQ.2 ) THEN
 *
 *                  Copy diagonal block to align whole system
 *
-                   CALL DLACPY( 'G', BM, BW, AF( BBPTR+BMN ),
-     $               LDBB, AF( BBPTR+2*BW*LDBB+BMN ), LDBB )
-                ENDIF
+               CALL DLACPY( 'G', BM, BW, AF( BBPTR+BMN ), LDBB,
+     $                      AF( BBPTR+2*BW*LDBB+BMN ), LDBB )
+            END IF
 *
-             ENDIF
+         END IF
 *
 *            LU factorization with partial pivoting
 *
-             IF (NPACT .NE. 2) THEN
+         IF( NPACT.NE.2 ) THEN
 *
-                CALL DGETRF(BM+BMN, BW, AF(BBPTR+BW*LDBB), LDBB,
-     $               IPIV(LN+1), INFO)
+            CALL DGETRF( BM+BMN, BW, AF( BBPTR+BW*LDBB ), LDBB,
+     $                   IPIV( LN+1 ), INFO )
 *
 *   Backsolve left side
 *
-                DO 301 J=BBPTR,BBPTR+BW*LDBB-1, LDBB
-                   DO 302 I=0, BM1-1
-                      AF(I+J) = ZERO
-  302              CONTINUE
-  301           CONTINUE
+            DO 150 J = BBPTR, BBPTR + BW*LDBB - 1, LDBB
+               DO 140 I = 0, BM1 - 1
+                  AF( I+J ) = ZERO
+  140          CONTINUE
+  150       CONTINUE
 *
-                CALL DLASWP(BW, AF(BBPTR), LDBB, 1, BW,
-     $               IPIV(LN+1), 1)
+            CALL DLASWP( BW, AF( BBPTR ), LDBB, 1, BW, IPIV( LN+1 ), 1 )
 *
-                CALL DTRSM('L','L','N','U', BW, BW, ONE,
-     $                AF(BBPTR+BW*LDBB), LDBB, AF(BBPTR), LDBB)
+            CALL DTRSM( 'L', 'L', 'N', 'U', BW, BW, ONE,
+     $                  AF( BBPTR+BW*LDBB ), LDBB, AF( BBPTR ), LDBB )
 *
 *               Use partial factors to update remainder
 *
-                CALL DGEMM( 'N', 'N', BM+BMN-BW, BW, BW,
-     $                -ONE, AF(BBPTR+BW*LDBB+BW), LDBB,
-     $                AF( BBPTR ), LDBB, ONE,
-     $                AF( BBPTR+BW ), LDBB )
+            CALL DGEMM( 'N', 'N', BM+BMN-BW, BW, BW, -ONE,
+     $                  AF( BBPTR+BW*LDBB+BW ), LDBB, AF( BBPTR ), LDBB,
+     $                  ONE, AF( BBPTR+BW ), LDBB )
 *
 *   Backsolve right side
 *
-                NRHS = BW
+            NRHS = BW
 *
-                CALL DLASWP(NRHS, AF(BBPTR+2*BW*LDBB), LDBB, 1, BW,
-     $               IPIV(LN+1), 1)
+            CALL DLASWP( NRHS, AF( BBPTR+2*BW*LDBB ), LDBB, 1, BW,
+     $                   IPIV( LN+1 ), 1 )
 *
-                CALL DTRSM('L','L','N','U', BW, NRHS, ONE,
-     $               AF(BBPTR+BW*LDBB), LDBB, AF(BBPTR+2*BW*LDBB), LDBB)
+            CALL DTRSM( 'L', 'L', 'N', 'U', BW, NRHS, ONE,
+     $                  AF( BBPTR+BW*LDBB ), LDBB,
+     $                  AF( BBPTR+2*BW*LDBB ), LDBB )
 *
 *               Use partial factors to update remainder
 *
-                CALL DGEMM( 'N', 'N', BM+BMN-BW, NRHS, BW,
-     $                -ONE, AF(BBPTR+BW*LDBB+BW), LDBB,
-     $                AF( BBPTR+2*BW*LDBB ), LDBB, ONE,
-     $                AF( BBPTR+2*BW*LDBB+BW ), LDBB )
+            CALL DGEMM( 'N', 'N', BM+BMN-BW, NRHS, BW, -ONE,
+     $                  AF( BBPTR+BW*LDBB+BW ), LDBB,
+     $                  AF( BBPTR+2*BW*LDBB ), LDBB, ONE,
+     $                  AF( BBPTR+2*BW*LDBB+BW ), LDBB )
 *
 *
 *     Test if processor is active in next round
 *
-                IF (MOD(MYCOL,2*NPSTR) .EQ. 0) THEN
+            IF( MOD( MYCOL, 2*NPSTR ).EQ.0 ) THEN
 *
 *                  Reset BM
 *
-                   BM = BM1+BM2-BW
+               BM = BM1 + BM2 - BW
 *
 *                  Local copying in the block bidiagonal area
 *
 *
-                   CALL DLACPY('G',BM,BW,
-     $                  AF(BBPTR+BW),
-     $                  LDBB, AF(BBPTR+BW*LDBB), LDBB)
-                   CALL DLACPY('G',BM,BW,
-     $                  AF(BBPTR+2*BW*LDBB+BW),
-     $                  LDBB, AF(BBPTR+2*BW*LDBB), LDBB)
+               CALL DLACPY( 'G', BM, BW, AF( BBPTR+BW ), LDBB,
+     $                      AF( BBPTR+BW*LDBB ), LDBB )
+               CALL DLACPY( 'G', BM, BW, AF( BBPTR+2*BW*LDBB+BW ), LDBB,
+     $                      AF( BBPTR+2*BW*LDBB ), LDBB )
 *
 *                  Zero out space that held original copy
 *
-                   DO 1020 J=0, BW-1
-                      DO 1021 I=0, BM-1
-                         AF(BBPTR+2*BW*LDBB+BW+J*LDBB+I) = ZERO
- 1021                 CONTINUE
- 1020              CONTINUE
+               DO 170 J = 0, BW - 1
+                  DO 160 I = 0, BM - 1
+                     AF( BBPTR+2*BW*LDBB+BW+J*LDBB+I ) = ZERO
+  160             CONTINUE
+  170          CONTINUE
 *
-                ENDIF
+            END IF
 *
-             ELSE
+         ELSE
 *
 *               Factor the final 2 by 2 block matrix
 *
-                CALL DGETRF(BM+BMN,BM+BMN, AF(BBPTR+BW*LDBB), LDBB,
-     $               IPIV(LN+1), INFO)
-             ENDIF
+            CALL DGETRF( BM+BMN, BM+BMN, AF( BBPTR+BW*LDBB ), LDBB,
+     $                   IPIV( LN+1 ), INFO )
+         END IF
 *
-          ENDIF
+      END IF
 *
 *        Last processor in an odd-sized NPACT skips to here
 *
-  250    CONTINUE
+  180 CONTINUE
 *
-         NPACT = (NPACT + 1)/2
-         NPSTR = NPSTR * 2
-         GOTO 200
+      NPACT = ( NPACT+1 ) / 2
+      NPSTR = NPSTR*2
+      GO TO 110
 *
-  300 CONTINUE
+  190 CONTINUE
 *     End loop over levels
 *
- 1000 CONTINUE
+  200 CONTINUE
 *     If error was found in Phase 1, processors jump here.
 *
 *     Free BLACS space used to hold standard-form grid.
@@ -1074,7 +1069,7 @@
          CALL BLACS_GRIDEXIT( ICTXT_NEW )
       END IF
 *
- 1234 CONTINUE
+  210 CONTINUE
 *     If this processor did not hold part of the grid it
 *        jumps here.
 *
@@ -1089,14 +1084,14 @@
 *
 *         Make INFO consistent across processors
 *
-          CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO,
-     $              -1, 0, 0 )
+      CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO, -1, 0,
+     $              0 )
 *
-          IF( MYCOL.EQ.0 ) THEN
-             CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
-          ELSE
-             CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
-          ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
+      ELSE
+         CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
+      END IF
 *
 *
       RETURN
@@ -1104,4 +1099,3 @@
 *     End of PDGBTRF
 *
       END
-*
