@@ -1,10 +1,10 @@
       SUBROUTINE PDGEQPF( M, N, A, IA, JA, DESCA, IPIV, TAU, WORK,
      $                    LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     March 14, 2000
 *
 *     .. Scalar Arguments ..
       INTEGER            IA, JA, INFO, LWORK, M, N
@@ -113,7 +113,7 @@
 *          was the global K-th column of sub( A ). IPIV is tied to the
 *          distributed matrix A.
 *
-*  TAU     (local output) DOUBLE PRECISION, array, dimension
+*  TAU     (local output) DOUBLE PRECISION array, dimension
 *          LOCc(JA+MIN(M,N)-1). This array contains the scalar factors
 *          TAU of the elementary reflectors. TAU is tied to the
 *          distributed matrix A.
@@ -457,15 +457,19 @@
      $      JJ = JJ + 1
          IF( MOD( J, DESCA( NB_ ) ).EQ.0 )
      $      ICURCOL = MOD( ICURCOL+1, NPCOL )
-         IF( MYROW.EQ.ICURROW ) THEN
-            CALL DGEBS2D( ICTXT, 'Columnwise', ' ', 1, JJA+NQ-JJ,
-     $                    A( II+( MIN( JJA+NQ-1, JJ )-1 )*LDA ), LDA )
-            CALL DCOPY( JJA+NQ-JJ, A( II+( MIN( JJA+NQ-1, JJ )-1)*LDA ),
-     $                  LDA, WORK( IPW+MIN( JJA+NQ-1, JJ )-1 ), 1 )
-         ELSE
-            CALL DGEBR2D( ICTXT, 'Columnwise', ' ', JJA+NQ-JJ, 1,
-     $                    WORK( IPW+MIN( JJA+NQ-1, JJ )-1 ),
-     $                    MAX( 1, NQ ), ICURROW, MYCOL )
+         IF( (JJA+NQ-JJ).GT.0 ) THEN
+            IF( MYROW.EQ.ICURROW ) THEN
+               CALL DGEBS2D( ICTXT, 'Columnwise', ' ', 1, JJA+NQ-JJ,
+     $                       A( II+( MIN( JJA+NQ-1, JJ )-1 )*LDA ),
+     $                       LDA )
+               CALL DCOPY( JJA+NQ-JJ, A( II+( MIN( JJA+NQ-1, JJ )
+     $                     -1)*LDA ), LDA, WORK( IPW+MIN( JJA+NQ-1,
+     $                    JJ )-1 ), 1 )
+            ELSE
+               CALL DGEBR2D( ICTXT, 'Columnwise', ' ', JJA+NQ-JJ, 1,
+     $                       WORK( IPW+MIN( JJA+NQ-1, JJ )-1 ),
+     $                       MAX( 1, NQ ), ICURROW, MYCOL )
+            END IF
          END IF
 *
          JN = MIN( ICEIL( J+1, DESCA( NB_ ) ) * DESCA( NB_ ),
@@ -481,7 +485,7 @@
                   IF( TEMP2.EQ.ONE ) THEN
                      IF( IA+M-1.GT.I ) THEN
                         CALL PDNRM2( IA+M-I-1, WORK( IPN+LL ), A, I+1,
-     $                               J+LL-JJ+1, DESCA, 1 )
+     $                               J+LL-JJ+2, DESCA, 1 )
                         WORK( IPN+NQ+LL ) = WORK( IPN+LL )
                      ELSE
                         WORK( IPN+LL ) = ZERO
