@@ -1,10 +1,10 @@
       SUBROUTINE PDLARZB( SIDE, TRANS, DIRECT, STOREV, M, N, K, L, V,
      $                    IV, JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     March 14, 2000
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIRECT, SIDE, STOREV, TRANS
@@ -243,7 +243,7 @@
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, DGEBR2D,
      $                   DGEBS2D,DGEMM, DGSUM2D, DLACPY,
      $                   DLASET, DTRBR2D, DTRBS2D, DTRMM,
-     $                   INFOG2L, PBDMATADD, PBDTRAN, PTOPGET, PXERBLA
+     $                   INFOG2L, PBDMATADD, PBDTRAN, PB_TOPGET, PXERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          MAX, MIN, MOD
@@ -505,7 +505,7 @@
 *
 *        Broadcast V to the other process rows.
 *
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
          IF( MYROW.EQ.IVROW ) THEN
             CALL DGEBS2D( ICTXT, 'Columnwise', COLBTOP, K, NQC2,
      $                    V( IOFFV ), LDV )
@@ -598,9 +598,10 @@
 *        C( IOFFC ) = C( IOFFC )  - WORK( IPW ) * WORK( IPV )
 *                     MPC2 x NQC2    MPC2 x K      K x NQC2
 *
-         CALL DGEMM( 'No transpose', 'No transpose', MPC2, NQC2, K,
-     $               -ONE, WORK( IPW ), LW, WORK( IPV ), LV, ONE,
-     $               C( IOFFC2 ), LDC )
+         IF( IOFFC2.GT.0 )
+     $      CALL DGEMM( 'No transpose', 'No transpose', MPC2, NQC2, K,
+     $                  -ONE, WORK( IPW ), LW, WORK( IPV ), LV, ONE,
+     $                  C( IOFFC2 ), LDC )
 *
       END IF
 *
