@@ -4,7 +4,7 @@
 *  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     April 3, 2000
+*     March 12, 2002 
 *
 *     .. Scalar Arguments ..
       INTEGER            BWL, BWU, INFO, JA, LAF, LWORK, N
@@ -371,7 +371,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, SAXPY, SDBTRF,
      $                   DESC_CONVERT, SGEMM, SGEMV, SGERV2D, SGESD2D,
-     $                   DLACPY, SLATCPY, STBTRS, STRMM, STRRV2D,
+     $                   SLACPY, SLATCPY, STBTRS, STRMM, STRRV2D,
      $                   STRSD2D, GLOBCHK, IGAMX2D, IGEBR2D, IGEBS2D,
      $                   PXERBLA, RESHAPE
 *     ..
