@@ -1,7 +1,7 @@
       SUBROUTINE PSLARFB( SIDE, TRANS, DIRECT, STOREV, M, N, K, V, IV,
      $                    JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
 *     May 1, 1997
@@ -235,7 +235,7 @@
      $                   NPV, NPV0, NPCOL, NPROW, NQC, NQC0, WIDE
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG1L, INFOG2L, PTOPGET,
+      EXTERNAL           BLACS_GRIDINFO, INFOG1L, INFOG2L, PB_TOPGET,
      $                   PBSTRAN, SGEBR2D, SGEBS2D, SGEMM,
      $                   SGSUM2D, SLACPY, SLASET, STRBR2D,
      $                   STRBS2D, STRMM
@@ -317,7 +317,7 @@
 *
 *           Broadcast V to the other process columns.
 *
-            CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+            CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
             IF( MYCOL.EQ.IVCOL ) THEN
                CALL SGEBS2D( ICTXT, 'Rowwise', ROWBTOP, MPC, K,
      $                       V( IOFFV ), LDV )
@@ -765,7 +765,7 @@
 *
 *           Broadcast V to the other process rows.
 *
-            CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+            CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
             IF( MYROW.EQ.IVROW ) THEN
                CALL SGEBS2D( ICTXT, 'Columnwise', COLBTOP, K, NQC,
      $                       V( IOFFV ), LDV )
