@@ -1,10 +1,10 @@
       SUBROUTINE PSLARZB( SIDE, TRANS, DIRECT, STOREV, M, N, K, L, V,
      $                    IV, JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     March 14, 2000
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIRECT, SIDE, STOREV, TRANS
@@ -241,7 +241,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, INFOG2L,
-     $                   PBSMATADD, PBSTRAN, PTOPGET, PXERBLA,
+     $                   PBSMATADD, PBSTRAN, PB_TOPGET, PXERBLA,
      $                   SGEBR2D, SGEBS2D, SGEMM,
      $                   SGSUM2D, SLACPY, SLASET, STRBR2D,
      $                   STRBS2D, STRMM
@@ -506,7 +506,7 @@
 *
 *        Broadcast V to the other process rows.
 *
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
          IF( MYROW.EQ.IVROW ) THEN
             CALL SGEBS2D( ICTXT, 'Columnwise', COLBTOP, K, NQC2,
      $                    V( IOFFV ), LDV )
@@ -599,9 +599,10 @@
 *        C( IOFFC ) = C( IOFFC )  - WORK( IPW ) * WORK( IPV )
 *                     MPC2 x NQC2    MPC2 x K      K x NQC2
 *
-         CALL SGEMM( 'No transpose', 'No transpose', MPC2, NQC2, K,
-     $               -ONE, WORK( IPW ), LW, WORK( IPV ), LV, ONE,
-     $               C( IOFFC2 ), LDC )
+         IF( IOFFC2.GT.0 ) 
+     $      CALL SGEMM( 'No transpose', 'No transpose', MPC2, NQC2, K,
+     $                  -ONE, WORK( IPW ), LW, WORK( IPV ), LV, ONE,
+     $                  C( IOFFC2 ), LDC )
 *
       END IF
 *
