@@ -1,10 +1,10 @@
       SUBROUTINE PSORMQL( SIDE, TRANS, M, N, K, A, IA, JA, DESCA, TAU,
      $                    C, IC, JC, DESCC, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE, TRANS
@@ -235,7 +235,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CHK1MAT, PCHK2MAT, PSLARFB,
-     $                   PSLARFT, PSORM2L, PTOPGET, PTOPSET, PXERBLA
+     $                   PSLARFT, PSORM2L, PB_TOPGET, PB_TOPSET, PXERBLA
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -366,8 +366,8 @@
       IF( M.EQ.0 .OR. N.EQ.0 .OR. K.EQ.0 )
      $   RETURN
 *
-      CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-      CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+      CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+      CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       IF( ( LEFT .AND. NOTRAN ) .OR.
      $    ( .NOT.LEFT .AND. .NOT.NOTRAN ) ) THEN
@@ -383,11 +383,11 @@
       IF( LEFT ) THEN
          NI = N
          IF( NOTRAN ) THEN
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
          ELSE
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
          END IF
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
       ELSE
          MI = M
       END IF
@@ -446,8 +446,8 @@
      $                 C, IC, JC, DESCC, WORK, LWORK, IINFO )
       END IF
 *
-      CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-      CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+      CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+      CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       WORK( 1 ) = REAL( LWMIN )
 *
