@@ -3,10 +3,10 @@
 *
 *
 *
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     August 7, 2001 
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS
@@ -403,7 +403,8 @@
      $                   PARAM_CHECK( 17, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, DESC_CONVERT, GLOBCHK, PXERBLA
+      EXTERNAL           BLACS_GRIDINFO, DESC_CONVERT, GLOBCHK, PXERBLA,
+     $                   RESHAPE
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
