@@ -1,16 +1,14 @@
-*
       SUBROUTINE PZHEEV( JOBZ, UPLO, N, A, IA, JA, DESCA, W, Z, IZ, JZ,
      $                   DESCZ, WORK, LWORK, RWORK, LRWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.6) --
-*
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     August 14, 2001 
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBZ, UPLO
-      INTEGER            IA, INFO, IZ, JA, JZ, LWORK, LRWORK, N
+      INTEGER            IA, INFO, IZ, JA, JZ, LRWORK, LWORK, N
 *     ..
 *     .. Array Arguments ..
       INTEGER            DESCA( * ), DESCZ( * )
@@ -19,14 +17,13 @@
 *     ..
 *
 *  Purpose
-*
 *  =======
 *
 *  PZHEEV computes selected eigenvalues and, optionally, eigenvectors
 *  of a real symmetric matrix A by calling the recommended sequence
 *  of ScaLAPACK routines.
 *
-*  In it's present form, PZHEEV assumes a homogeneous system and makes
+*  In its present form, PZHEEV assumes a homogeneous system and makes
 *  only spot checks of the consistency of the eigenvalues across the
 *  different processes.  Because of this, it is possible that a
 *  heterogeneous system may return incorrect results without any error
@@ -133,7 +130,8 @@
 *          eigenvalues in ascending order.
 *
 *  Z       (local output) COMPLEX*16 array,
-*          global dimension (N, N), local dimension ( LLD_Z, LOCc(JZ+N-1) )
+*          global dimension (N, N),
+*          local dimension (LLD_Z, LOCc(JZ+N-1))
 *          If JOBZ = 'V', then on normal exit the first M columns of Z
 *          contain the orthonormal eigenvectors of the matrix
 *          corresponding to the selected eigenvalues.
@@ -184,7 +182,8 @@
 *
 *  RWORK   (local workspace/output) COMPLEX*16 array,
 *          dimension (LRWORK)
-*          On output RWORK(1) returns the real workspace needed to
+*          On output RWORK(1) returns the
+*          DOUBLE PRECISION workspace needed to
 *          guarantee completion.  If the input parameters are incorrect,
 *          RWORK(1) may also be incorrect.
 *
@@ -242,9 +241,9 @@
       PARAMETER          ( BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
      $                   CTXT_ = 2, M_ = 3, N_ = 4, MB_ = 5, NB_ = 6,
      $                   RSRC_ = 7, CSRC_ = 8, LLD_ = 9 )
-      DOUBLE PRECISION   ONE, ZERO
+      DOUBLE PRECISION   ZERO, ONE
       PARAMETER          ( ZERO = 0.0D+0, ONE = 1.0D+0 )
-      COMPLEX*16         CONE, CZERO
+      COMPLEX*16         CZERO, CONE
       PARAMETER          ( CZERO = ( 0.0D+0, 0.0D+0 ),
      $                   CONE = ( 1.0D+0, 0.0D+0 ) )
       INTEGER            ITHVAL
@@ -252,16 +251,16 @@
 *     ..
 *     .. Local Scalars ..
       LOGICAL            LOWER, WANTZ
-      INTEGER            CONTEXTC, CSRC_A, I, IACOL, IAROW, ICOFFA, 
-     $                   IINFO, INDD, INDE, INDRD, INDRE, INDRWORK, 
-     $                   INDTAU, INDWORK, INDWORK2, IROFFA, IROFFZ, 
-     $                   ISCALE, IZROW, J, K, LDC, LLRWORK, LLWORK, 
-     $                   LRWMIN, LWMIN, MB_A, MB_Z, MYCOL, MYPCOLC, 
-     $                   MYPROWC, MYROW, NB, NB_A, NB_Z, NP0, NPCOL, 
-     $                   NPCOLC, NPROCS, NPROW, NPROWC, NQ0, NRC, 
-     $                   RSIZEZSTEQR2, RSRC_A, RSRC_Z, SIZEPZHETRD, 
+      INTEGER            CONTEXTC, CSRC_A, I, IACOL, IAROW, ICOFFA,
+     $                   IINFO, INDD, INDE, INDRD, INDRE, INDRWORK,
+     $                   INDTAU, INDWORK, INDWORK2, IROFFA, IROFFZ,
+     $                   ISCALE, IZROW, J, K, LDC, LLRWORK, LLWORK,
+     $                   LRMIN, LRWMIN, LWMIN, MB_A, MB_Z, MYCOL,
+     $                   MYPCOLC, MYPROWC, MYROW, NB, NB_A, NB_Z, NP0,
+     $                   NPCOL, NPCOLC, NPROCS, NPROW, NPROWC, NQ0, NRC,
+     $                   RSIZEZSTEQR2, RSRC_A, RSRC_Z, SIZEPZHETRD,
      $                   SIZEPZUNMTR, SIZEZSTEQR2
-      DOUBLE PRECISION   ANRM, BIGNUM, EPS, RMAX, RMIN, SAFMIN, SIGMA, 
+      DOUBLE PRECISION   ANRM, BIGNUM, EPS, RMAX, RMIN, SAFMIN, SIGMA,
      $                   SMLNUM
 *     ..
 *     .. Local Arrays ..
@@ -271,17 +270,18 @@
       LOGICAL            LSAME
       INTEGER            INDXG2P, NUMROC, SL_GRIDRESHAPE
       DOUBLE PRECISION   PDLAMCH, PZLANHE
-      EXTERNAL           INDXG2P, LSAME, NUMROC, PDLAMCH, PZLANHE, 
-     $                   SL_GRIDRESHAPE
+      EXTERNAL           LSAME, INDXG2P, NUMROC, SL_GRIDRESHAPE,
+     $                   PDLAMCH, PZLANHE
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, CHK1MAT, DCOPY, 
-     $                   DESCINIT, DGAMN2D, DGAMX2D, DSCAL, PCHK1MAT, 
-     $                   PCHK2MAT, PXERBLA, PZELGET, PZGEMR2D, PZHETRD, 
+      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, CHK1MAT, DCOPY,
+     $                   DESCINIT, DGAMN2D, DGAMX2D, DSCAL, PCHK1MAT,
+     $                   PCHK2MAT, PXERBLA, PZELGET, PZGEMR2D, PZHETRD,
      $                   PZLASCL, PZLASET, PZUNMTR, ZSTEQR2
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          DBLE, DCMPLX, ICHAR, MAX, MIN, MOD, SQRT
+      INTRINSIC          ABS, DBLE, DCMPLX, ICHAR, INT, MAX, MIN, MOD,
+     $                   SQRT
 *     ..
 *     .. Executable Statements ..
 *       This is just to keep ftnchek and toolpack/1 happy
@@ -297,6 +297,18 @@
 *
       CALL BLACS_GRIDINFO( DESCA( CTXT_ ), NPROW, NPCOL, MYROW, MYCOL )
       INFO = 0
+*
+*     Initialize pointer to some safe value
+*
+      INDTAU = 1
+      INDD = 1
+      INDE = 1
+      INDWORK = 1
+      INDWORK2 = 1
+*
+      INDRE = 1
+      INDRD = 1
+      INDRWORK = 1
 *
       WANTZ = LSAME( JOBZ, 'V' )
       IF( NPROW.EQ.-1 ) THEN
@@ -306,7 +318,7 @@
             INFO = -( 1200+CTXT_ )
          END IF
       END IF
-      IF( INFO .EQ. 0 ) THEN
+      IF( INFO.EQ.0 ) THEN
          CALL CHK1MAT( N, 3, N, 3, IA, JA, DESCA, 7, INFO )
          IF( WANTZ )
      $      CALL CHK1MAT( N, 3, N, 3, IZ, JZ, DESCZ, 12, INFO )
@@ -344,40 +356,32 @@
                IZROW = INDXG2P( 1, NB_A, MYROW, RSRC_Z, NPROW )
             END IF
 *
-*           Complex work space for PZHETRD
+*           COMPLEX*16 work space for PZHETRD
 *
             CALL PZHETRD( UPLO, N, A, IA, JA, DESCA, RWORK( INDD ),
      $                    RWORK( INDE ), WORK( INDTAU ),
      $                    WORK( INDWORK ), -1, IINFO )
-            SIZEPZHETRD = WORK( 1 )
+            SIZEPZHETRD = INT( ABS( WORK( 1 ) ) )
 *
-*           Complex work space for PZUNMTR
+*           COMPLEX*16 work space for PZUNMTR
 *
             IF( WANTZ ) THEN
                CALL PZUNMTR( 'L', UPLO, 'N', N, N, A, IA, JA, DESCA,
      $                       WORK( INDTAU ), Z, IZ, JZ, DESCZ,
      $                       WORK( INDWORK ), -1, IINFO )
-               SIZEPZUNMTR = WORK( 1 )
+               SIZEPZUNMTR = INT( ABS( WORK( 1 ) ) )
             ELSE
                SIZEPZUNMTR = 0
             END IF
 *
-*           Real work space for ZSTEQR2
+*           DOUBLE PRECISION work space for ZSTEQR2
 *
             IF( WANTZ ) THEN
-               RSIZEZSTEQR2 = MIN( 1, 2*N - 2 )
+               RSIZEZSTEQR2 = MIN( 1, 2*N-2 )
             ELSE
                RSIZEZSTEQR2 = 0
             END IF
 *
-*           Complex work space for ZSTEQR2
-*
-            IF( WANTZ ) THEN
-               SIZEZSTEQR2 = N*LDC
-            ELSE
-               SIZEZSTEQR2 = 0
-            END IF
-*
 *           Initialize the context of the single column distributed
 *           matrix required by ZSTEQR2. This specific distribution
 *           allows each process to do 1/pth of the work updating matrix
@@ -392,8 +396,16 @@
      $                              MYPCOLC )
                NRC = NUMROC( N, NB_A, MYPROWC, 0, NPROCS )
                LDC = MAX( 1, NRC )
-               CALL DESCINIT( DESCQR, N, N, NB, NB, 0, 0, CONTEXTC,
-     $                        LDC, INFO )
+               CALL DESCINIT( DESCQR, N, N, NB, NB, 0, 0, CONTEXTC, LDC,
+     $                        INFO )
+            END IF
+*
+*           COMPLEX*16 work space for ZSTEQR2
+*
+            IF( WANTZ ) THEN
+               SIZEZSTEQR2 = N*LDC
+            ELSE
+               SIZEZSTEQR2 = 0
             END IF
 *
 *           Set up pointers into the WORK array
@@ -471,8 +483,8 @@
          END IF
          IDUM2( 3 ) = 3
          IF( WANTZ ) THEN
-            CALL PCHK2MAT( N, 3, N, 3, IA, JA, DESCA, 7, N, 3, N, 3,
-     $                     IZ, JZ, DESCZ, 12, 3, IDUM1, IDUM2, INFO )
+            CALL PCHK2MAT( N, 3, N, 3, IA, JA, DESCA, 7, N, 3, N, 3, IZ,
+     $                     JZ, DESCZ, 12, 3, IDUM1, IDUM2, INFO )
          ELSE
             CALL PCHK1MAT( N, 3, N, 3, IA, JA, DESCA, 7, 3, IDUM1,
      $                     IDUM2, INFO )
@@ -496,8 +508,8 @@
 *
       ISCALE = 0
 *
-      ANRM = PZLANHE( 'M', UPLO, N, A, IA, JA, DESCA, 
-     $                RWORK( INDRWORK ) )
+      ANRM = PZLANHE( 'M', UPLO, N, A, IA, JA, DESCA,
+     $       RWORK( INDRWORK ) )
 *
 *
       IF( ANRM.GT.ZERO .AND. ANRM.LT.RMIN ) THEN
@@ -509,8 +521,7 @@
       END IF
 *
       IF( ISCALE.EQ.1 ) THEN
-         CALL PZLASCL( UPLO, ONE, SIGMA, N, N, A, IA, JA, DESCA,
-     $                 IINFO )
+         CALL PZLASCL( UPLO, ONE, SIGMA, N, N, A, IA, JA, DESCA, IINFO )
       END IF
 *
 *     Reduce symmetric matrix to tridiagonal form.
@@ -545,7 +556,7 @@
          CALL PZLASET( 'Full', N, N, CZERO, CONE, WORK( INDWORK ), 1, 1,
      $                 DESCQR )
 *
-*        ZSTEQR2 is a modified version of LAPACK's ZSTEQR.  The
+*        ZSTEQR2 is a modified version of LAPACK's CSTEQR.  The
 *        modifications allow each process to perform partial updates
 *        to matrix Q.
 *
@@ -595,22 +606,26 @@
          K = ITHVAL
       END IF
 *
+      LRMIN = INT( RWORK( 1 ) )
+      INDTAU = 0
+      INDE = INDTAU + J
       DO 40 I = 1, J
-         WORK( I+INDTAU ) = W( ( I-1 )*K+1 )
-         WORK( I+INDE ) = W( ( I-1 )*K+1 )
+         RWORK( I+INDTAU ) = W( ( I-1 )*K+1 )
+         RWORK( I+INDE ) = W( ( I-1 )*K+1 )
    40 CONTINUE
 *
-      CALL DGAMN2D( DESCA( CTXT_ ), 'a', ' ', J, 1, WORK( 1+INDTAU ),
+      CALL DGAMN2D( DESCA( CTXT_ ), 'All', ' ', J, 1, RWORK( 1+INDTAU ),
+     $              J, 1, 1, -1, -1, 0 )
+      CALL DGAMX2D( DESCA( CTXT_ ), 'All', ' ', J, 1, RWORK( 1+INDE ),
      $              J, 1, 1, -1, -1, 0 )
-      CALL DGAMX2D( DESCA( CTXT_ ), 'a', ' ', J, 1, WORK( 1+INDE ), J,
-     $              1, 1, -1, -1, 0 )
 *
       DO 50 I = 1, J
-         IF( INFO.EQ.0 .AND. ( WORK( I+INDTAU )-WORK( I+INDE ).NE.
+         IF( INFO.EQ.0 .AND. ( RWORK( I+INDTAU )-RWORK( I+INDE ).NE.
      $       ZERO ) ) THEN
             INFO = N + 1
          END IF
    50 CONTINUE
+      RWORK( 1 ) = LRMIN
 *
       RETURN
 *
