@@ -1,7 +1,7 @@
       SUBROUTINE PZLARFB( SIDE, TRANS, DIRECT, STOREV, M, N, K, V, IV,
      $                    JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
 *     May 1, 1997
@@ -236,7 +236,7 @@
      $                   NPV, NPV0, NPCOL, NPROW, NQC, NQC0, WIDE
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG1L, INFOG2L, PTOPGET,
+      EXTERNAL           BLACS_GRIDINFO, INFOG1L, INFOG2L, PB_TOPGET,
      $                   PBZTRAN, ZGEBR2D, ZGEBS2D, ZGEMM,
      $                   ZGSUM2D, ZLACPY, ZLASET, ZTRBR2D,
      $                   ZTRBS2D, ZTRMM
@@ -318,7 +318,7 @@
 *
 *           Broadcast V to the other process columns.
 *
-            CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+            CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
             IF( MYCOL.EQ.IVCOL ) THEN
                CALL ZGEBS2D( ICTXT, 'Rowwise', ROWBTOP, MPC, K,
      $                       V( IOFFV ), LDV )
@@ -768,7 +768,7 @@
 *
 *           Broadcast V to the other process rows.
 *
-            CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+            CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
             IF( MYROW.EQ.IVROW ) THEN
                CALL ZGEBS2D( ICTXT, 'Columnwise', COLBTOP, K, NQC,
      $                       V( IOFFV ), LDV )
