@@ -1,10 +1,10 @@
       SUBROUTINE PZLARFC( SIDE, M, N, V, IV, JV, DESCV, INCV, TAU,
      $                   C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.5) --
+*  -- ScaLAPACK auxiliary routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE
@@ -245,7 +245,7 @@
       COMPLEX*16         TAULOC
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PTOPGET, PBZTRNV,
+      EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBZTRNV,
      $                   ZCOPY, ZGEBR2D, ZGEBS2D, ZGEMV,
      $                   ZGERC, ZGERV2D, ZGESD2D, ZGSUM2D,
      $                   ZLASET
@@ -508,7 +508,7 @@
 *
 *              Broadcast column vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
                IF( MYCOL.EQ.IVCOL ) THEN
 *
                   IPW = MP+1
@@ -707,7 +707,8 @@
 *
 *              Broadcast row vector V
 *
-               CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+               CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise',
+     $                         COLBTOP )
                IF( MYROW.EQ.IVROW ) THEN
 *
                   IPW = NQ+1
