@@ -1,10 +1,10 @@
       SUBROUTINE PZUNM2L( SIDE, TRANS, M, N, K, A, IA, JA, DESCA, TAU,
      $                    C, IC, JC, DESCC, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE, TRANS
@@ -225,8 +225,8 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, CHK1MAT, INFOG2L,
-     $                   PTOPGET, PTOPSET, PXERBLA, PZELSET, PZELSET2,
-     $                   PZLARF, PZLARFC, ZGEBR2D, ZGEBS2D,
+     $                   PB_TOPGET, PB_TOPSET, PXERBLA, PZELSET,
+     $                   PZELSET2, PZLARF, PZLARFC, ZGEBR2D, ZGEBS2D,
      $                   ZGERV2D, ZGESD2D, ZSCAL
 *     ..
 *     .. External Functions ..
@@ -378,8 +378,8 @@
 *
       ELSE
 *
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
          IF( LEFT .AND. NOTRAN .OR. .NOT.LEFT .AND. .NOT.NOTRAN ) THEN
             J1 = JA
@@ -394,11 +394,11 @@
          IF( LEFT ) THEN
             NI = N
             IF( NOTRAN ) THEN
-               CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
+               CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
             ELSE
-               CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
+               CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
             END IF
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
          ELSE
             MI = M
          END IF
@@ -431,8 +431,8 @@
 *
    10    CONTINUE
 *
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       END IF
 *
