@@ -1,10 +1,10 @@
       SUBROUTINE PZUNMRQ( SIDE, TRANS, M, N, K, A, IA, JA, DESCA, TAU,
      $                    C, IC, JC, DESCC, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE, TRANS
@@ -234,8 +234,8 @@
       INTEGER            IDUM1( 4 ), IDUM2( 4 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, CHK1MAT, PCHK2MAT, PTOPGET,
-     $                   PTOPSET, PXERBLA, PZLARFB, PZLARFT,
+      EXTERNAL           BLACS_GRIDINFO, CHK1MAT, PCHK2MAT, PB_TOPGET,
+     $                   PB_TOPSET, PXERBLA, PZLARFB, PZLARFT,
      $                   PZUNMR2
 *     ..
 *     .. External Functions ..
@@ -366,8 +366,8 @@
       IF( M.EQ.0 .OR. N.EQ.0 .OR. K.EQ.0 )
      $   RETURN
 *
-      CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-      CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+      CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+      CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       IF( ( LEFT .AND. .NOT.NOTRAN ) .OR.
      $    ( .NOT.LEFT .AND. NOTRAN ) ) THEN
@@ -386,11 +386,11 @@
          NI = N
       ELSE
          MI = M
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', ' ' )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', ' ' )
          IF( NOTRAN ) THEN
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', 'I-ring' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', 'I-ring' )
          ELSE
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', 'D-ring' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', 'D-ring' )
          END IF
       END IF
 *
@@ -452,8 +452,8 @@
      $                 C, IC, JC, DESCC, WORK, LWORK, IINFO )
       END IF
 *
-      CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-      CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+      CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+      CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       WORK( 1 ) = DCMPLX( DBLE( LWMIN ) )
 *
