@@ -9,7 +9,7 @@
 *  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     March 15, 2002 
 *
 *     .. Scalar Arguments ..
       CHARACTER          SUBTESTS, UPLO
@@ -1061,7 +1061,7 @@
 *
          NP0 = NUMROC( N, NB, 0, 0, NPROW )
          NQ0 = NUMROC( MAX( N, 1 ), NB, 0, 0, NPCOL )
-         LHEEVDSIZE = MAX( 1, 7*N+3*NP0*NQ0 )
+         LHEEVDSIZE = 1 + 9*N + 3*NP0*NQ0
          ISIZEHEEVD = MAX( 1, 2+7*N+8*NPCOL )
 *
          CALL PCSDPSUBTST( WKNOWN, UPLO, N, THRESH, ABSTOL, A, COPYA, Z,
